==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/core/imergedatafilter.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IMERGEDATAFILTER_H
#define IMERGEDATAFILTER_H


#include "igenericfilter.h"
#include <vtkDataSetToDataSetFilter.h>


class iMergeDataFilter : public iGenericFilter<vtkDataSetToDataSetFilter,vtkDataSet,vtkDataSet>
{

	IGENERICFILTER_DECLARE(iMergeDataFilter);
	
public:

	void SetDataInput(int rank, vtkDataSet *input);
	vtkDataSet* GetDataInput(int rank);
	bool HasData(int rank);

protected:
	
	virtual void InitExecution();
	virtual void ProduceOutput();

	bool AreDataSetsCompatible(vtkDataSet *ds1, vtkDataSet *ds2) const;
};

#endif

==> ifrit_3.2.8.orig.tar.gz: ifrit-3.2.8/core/imergedatafilter.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IMERGEDATAFILTER_H
#define IMERGEDATAFILTER_H


#include "igenericfilter.h"
#include <vtkDataSetToDataSetFilter.h>


class iMergeDataFilter : public iGenericFilter<vtkDataSetToDataSetFilter,vtkDataSet,vtkDataSet>
{

	IGENERICFILTER_DECLARE(iMergeDataFilter,vtkDataSetToDataSetFilter);
	
public:

	inline vtkDataSet* GetDataInput(){ return mDataInput; }
	void SetDataInput(int rank, vtkDataSet *input);
	bool HasData(int rank);

protected:
	
	virtual void InitExecution();
	virtual void ProduceOutput();

private:

	bool AreDataSetsCompatible(vtkDataSet *ds1, vtkDataSet *ds2) const;

	int mDataRank;
	vtkDataSet *mDataInput;
};

#endif
